@@ -3,13 +3,6 @@ from PyQt5.QtWidgets import *
 from PyQt5.QtWebEngineWidgets import QWebEngineView
 from PyQt5 import QtCore, QtGui
 import mysql.connector
-from pathlib import Path
-
-sys.path.append(str(Path(__file__).resolve().parents[1]))
-try:
-    from source import connection
-except:
-    from scpantheon.source import connection
 
 def myconnect():
     global mydb,mycursor
@@ -71,11 +64,12 @@ class Ui_Dialog(QWidget, object):
         self.layout2 = QVBoxLayout(Dialog)
         self.layout2.setObjectName("Layout2")
 
+
         # render website inside qt application
         self.centralwidget = QWidget(Dialog)
         self.centralwidget.setObjectName("centralwidget")
         self.webEngineView = QWebEngineView(self.centralwidget)
-        self.loadPage()
+        self.webEngineView.load(QtCore.QUrl.fromLocalFile("D:/anaconda/Lib/site-packages/Pantheon/scpantheon/embed.html"))
         self.layout2.addWidget(self.webEngineView)
 
 
@@ -88,18 +82,12 @@ class Ui_Dialog(QWidget, object):
         self.layout2.addWidget(self.btn_Extensions)
         self.layout2.addWidget(self.btn_Data)
 
+
         self.retranslateUi(Dialog) 
         self.buttonBox.accepted.connect(Dialog.accept)
         self.buttonBox.rejected.connect(Dialog.reject)
         QtCore.QMetaObject.connectSlotsByName(Dialog)
 
-    def loadPage(self):
-        Func = open("embed.html","w")
-        Func.write("<!doctype html>\n<html>\n<iframe src='http://localhost:5006/'\nname='thumbnails'\nframeborder='0'\nstyle='width: 100%; height: 2000px;'>\n</html>")
-        Func.close()
-        with open('embed.html', 'r') as f:
-            html = f.read()
-            self.webEngineView.setHtml(html)
 
     def slot_btn_Extensions(self):
         Extensions = QFileDialog.getExistingDirectory(self,"Choose Extensions",self.cwd) # 起始路径
